@@ -13,6 +13,11 @@ from ..api.verification import VerificationRunEventHandler
 from .exceptions import InvalidVerification
 
 __all__ = ["ensure_verification_is_valid", "run_verification"]
+# this changed in CTK 1.10
+try:
+    CONTINUOUS = Strategy.CONTINUOUS
+except AttributeError:
+    CONTINUOUS = Strategy.CONTINOUS
 
 
 @with_cache
@@ -60,7 +65,7 @@ def ensure_verification_is_valid(experiment: Experiment):
 def run_verification(experiment: Experiment,
                      settings: Settings = None,
                      experiment_vars: Dict[str, Any] = None,
-                     strategy: Strategy = Strategy.CONTINOUS,
+                     strategy: Strategy = CONTINUOUS,
                      schedule: Schedule = None) -> Journal:
     with Runner(strategy, schedule) as runner:
         runner.register_event_handler(RunEventHandler())
